/* OGMDvd - A wrapper library around libdvdread
 * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef __OGMDVD_H__
#define __OGMDVD_H__

#include <ogmdvd-audio.h>
#include <ogmdvd-disc.h>
#include <ogmdvd-drive.h>
#include <ogmdvd-enums.h>
#include <ogmdvd-labels.h>
#include <ogmdvd-monitor.h>
#include <ogmdvd-parser.h>
#include <ogmdvd-reader.h>
#include <ogmdvd-stream.h>
#include <ogmdvd-subp.h>
#include <ogmdvd-title.h>
#include <ogmdvd-types.h>

#endif /* __OGMDVD_H__ */

